Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelFrame
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Video frame level annotation results for label detection.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Confidence that the label is accurate.
-
#time_offset ⇒ String
Time-offset, relative to the beginning of the video, corresponding to the video frame for this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1LabelFrame
constructor
A new instance of GoogleCloudVideointelligenceV1LabelFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1LabelFrame
Returns a new instance of GoogleCloudVideointelligenceV1LabelFrame.
418 419 420 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Confidence that the label is accurate. Range: [0, 1].
Corresponds to the JSON property confidence
410 411 412 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 410 def confidence @confidence end |
#time_offset ⇒ String
Time-offset, relative to the beginning of the video, corresponding to the
video frame for this location.
Corresponds to the JSON property timeOffset
416 417 418 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 416 def time_offset @time_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
423 424 425 426 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 423 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @time_offset = args[:time_offset] if args.key?(:time_offset) end |