Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoAnnotationResults
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoAnnotationResults
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Annotation results for a single video.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only).
-
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1FaceAnnotation>
Deprecated.
-
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1FaceDetectionAnnotation>
Face detection annotations.
-
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Label annotations on frame level.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
-
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
-
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1PersonDetectionAnnotation>
Person detection annotations.
-
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
-
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
-
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
-
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoSegment>
Shot annotations.
-
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Topical label annotations on shot level.
-
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Presence label annotations on shot level.
-
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1SpeechTranscription>
Speech transcription.
-
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1TextAnnotation>
OCR text detection and tracking.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationResults
constructor
A new instance of GoogleCloudVideointelligenceV1VideoAnnotationResults.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationResults
Returns a new instance of GoogleCloudVideointelligenceV1VideoAnnotationResults.
1093 1094 1095 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
996 997 998 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 996 def error @error end |
#explicit_annotation ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1ExplicitContentAnnotation
Explicit content annotation (based on per-frame visual signals only). If no
explicit content has been detected in a frame, no annotations are present for
that frame.
Corresponds to the JSON property explicitAnnotation
1003 1004 1005 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1003 def explicit_annotation @explicit_annotation end |
#face_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1FaceAnnotation>
Deprecated. Please use face_detection_annotations instead.
Corresponds to the JSON property faceAnnotations
1008 1009 1010 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1008 def face_annotations @face_annotations end |
#face_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1FaceDetectionAnnotation>
Face detection annotations.
Corresponds to the JSON property faceDetectionAnnotations
1013 1014 1015 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1013 def face_detection_annotations @face_detection_annotations end |
#frame_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Label annotations on frame level. There is exactly one element for each unique
label.
Corresponds to the JSON property frameLabelAnnotations
1019 1020 1021 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1019 def frame_label_annotations @frame_label_annotations end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
1024 1025 1026 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1024 def input_uri @input_uri end |
#logo_recognition_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LogoRecognitionAnnotation>
Annotations for list of logos detected, tracked and recognized in video.
Corresponds to the JSON property logoRecognitionAnnotations
1029 1030 1031 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1029 def logo_recognition_annotations @logo_recognition_annotations end |
#object_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1ObjectTrackingAnnotation>
Annotations for list of objects detected and tracked in video.
Corresponds to the JSON property objectAnnotations
1034 1035 1036 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1034 def object_annotations @object_annotations end |
#person_detection_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1PersonDetectionAnnotation>
Person detection annotations.
Corresponds to the JSON property personDetectionAnnotations
1039 1040 1041 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1039 def person_detection_annotations @person_detection_annotations end |
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
Corresponds to the JSON property segment
1044 1045 1046 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1044 def segment @segment end |
#segment_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Topical label annotations on video level or user-specified segment level.
There is exactly one element for each unique label.
Corresponds to the JSON property segmentLabelAnnotations
1050 1051 1052 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1050 def segment_label_annotations @segment_label_annotations end |
#segment_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Presence label annotations on video level or user-specified segment level.
There is exactly one element for each unique label. Compared to the existing
topical segment_label_annotations, this field presents more fine-grained,
segment-level labels detected in video content and is made available only when
the client sets LabelDetectionConfig.model to "builtin/latest" in the
request.
Corresponds to the JSON property segmentPresenceLabelAnnotations
1060 1061 1062 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1060 def segment_presence_label_annotations @segment_presence_label_annotations end |
#shot_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1VideoSegment>
Shot annotations. Each shot is represented as a video segment.
Corresponds to the JSON property shotAnnotations
1065 1066 1067 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1065 def shot_annotations @shot_annotations end |
#shot_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Topical label annotations on shot level. There is exactly one element for each
unique label.
Corresponds to the JSON property shotLabelAnnotations
1071 1072 1073 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1071 def shot_label_annotations @shot_label_annotations end |
#shot_presence_label_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1LabelAnnotation>
Presence label annotations on shot level. There is exactly one element for
each unique label. Compared to the existing topical shot_label_annotations,
this field presents more fine-grained, shot-level labels detected in video
content and is made available only when the client sets LabelDetectionConfig.
model to "builtin/latest" in the request.
Corresponds to the JSON property shotPresenceLabelAnnotations
1080 1081 1082 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1080 def shot_presence_label_annotations @shot_presence_label_annotations end |
#speech_transcriptions ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1SpeechTranscription>
Speech transcription.
Corresponds to the JSON property speechTranscriptions
1085 1086 1087 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1085 def speech_transcriptions @speech_transcriptions end |
#text_annotations ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1TextAnnotation>
OCR text detection and tracking. Annotations for list of detected text
snippets. Each will have list of frame information associated with it.
Corresponds to the JSON property textAnnotations
1091 1092 1093 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1091 def text_annotations @text_annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1098 def update!(**args) @error = args[:error] if args.key?(:error) @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation) @face_annotations = args[:face_annotations] if args.key?(:face_annotations) @face_detection_annotations = args[:face_detection_annotations] if args.key?(:face_detection_annotations) @frame_label_annotations = args[:frame_label_annotations] if args.key?(:frame_label_annotations) @input_uri = args[:input_uri] if args.key?(:input_uri) @logo_recognition_annotations = args[:logo_recognition_annotations] if args.key?(:logo_recognition_annotations) @object_annotations = args[:object_annotations] if args.key?(:object_annotations) @person_detection_annotations = args[:person_detection_annotations] if args.key?(:person_detection_annotations) @segment = args[:segment] if args.key?(:segment) @segment_label_annotations = args[:segment_label_annotations] if args.key?(:segment_label_annotations) @segment_presence_label_annotations = args[:segment_presence_label_annotations] if args.key?(:segment_presence_label_annotations) @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations) @shot_label_annotations = args[:shot_label_annotations] if args.key?(:shot_label_annotations) @shot_presence_label_annotations = args[:shot_presence_label_annotations] if args.key?(:shot_presence_label_annotations) @speech_transcriptions = args[:speech_transcriptions] if args.key?(:speech_transcriptions) @text_annotations = args[:text_annotations] if args.key?(:text_annotations) end |