Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1WordInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Word-specific information for recognized words. Word information is only included in the response when certain request parameters are set, such as enable_word_time_offsets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1WordInfo

Returns a new instance of GoogleCloudVideointelligenceV1WordInfo.



1198
1199
1200
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Output only. The confidence estimate between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. This field is set only for the top alternative. This field is not guaranteed to be accurate and users should not rely on it to be always provided. The default of 0.0 is a sentinel value indicating confidence was not set. Corresponds to the JSON property confidence

Returns:

  • (Float)


1160
1161
1162
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1160

def confidence
  @confidence
end

#end_timeString

Time offset relative to the beginning of the audio, and corresponding to the end of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property endTime

Returns:

  • (String)


1168
1169
1170
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1168

def end_time
  @end_time
end

#speaker_labelString

Output only. A distinct string value is assigned for every speaker within the audio. This field specifies which one of those speakers was detected to have spoken this word. Corresponds to the JSON property speakerLabel

Returns:

  • (String)


1175
1176
1177
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1175

def speaker_label
  @speaker_label
end

#speaker_tagFixnum

Output only. A distinct integer value is assigned for every speaker within the audio. This field specifies which one of those speakers was detected to have spoken this word. Value ranges from 1 up to diarization_speaker_count, and is only set if speaker diarization is enabled. Corresponds to the JSON property speakerTag

Returns:

  • (Fixnum)


1183
1184
1185
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1183

def speaker_tag
  @speaker_tag
end

#start_timeString

Time offset relative to the beginning of the audio, and corresponding to the start of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property startTime

Returns:

  • (String)


1191
1192
1193
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1191

def start_time
  @start_time
end

#wordString

The word corresponding to this set of information. Corresponds to the JSON property word

Returns:

  • (String)


1196
1197
1198
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1196

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1203
1204
1205
1206
1207
1208
1209
1210
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1203

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @end_time = args[:end_time] if args.key?(:end_time)
  @speaker_label = args[:speaker_label] if args.key?(:speaker_label)
  @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag)
  @start_time = args[:start_time] if args.key?(:start_time)
  @word = args[:word] if args.key?(:word)
end