Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Status of exporting annotation response to user specified output_uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Returns a new instance of GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus.



1425
1426
1427
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. State of the output_uri export. Corresponds to the JSON property state

Returns:

  • (String)


1413
1414
1415
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1413

def state
  @state
end

#statusGoogle::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1423
1424
1425
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1423

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1430
1431
1432
1433
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 1430

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
end