Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress.
2156 2157 2158 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2156 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
2122 2123 2124 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2122 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
2128 2129 2130 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2128 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
2133 2134 2135 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2133 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
2139 2140 2141 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2139 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1beta2VideoSegment
Video segment.
Corresponds to the JSON property segment
2144 2145 2146 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2144 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
2149 2150 2151 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2149 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
2154 2155 2156 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2154 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2161 2162 2163 2164 2165 2166 2167 2168 2169 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2161 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |