Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Alternative hypotheses (a.k.a. n-best list).
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Output only.
-
#transcript ⇒ String
Transcript text representing the words that the user spoke.
-
#words ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1WordInfo>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1SpeechRecognitionAlternative.
3086 3087 3088 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3086 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Output only. The confidence estimate between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. This field is set only for the top alternative. This field is not
guaranteed to be accurate and users should not rely on it to be always
provided. The default of 0.0 is a sentinel value indicating confidence was
not set.
Corresponds to the JSON property confidence
3072 3073 3074 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3072 def confidence @confidence end |
#transcript ⇒ String
Transcript text representing the words that the user spoke.
Corresponds to the JSON property transcript
3077 3078 3079 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3077 def transcript @transcript end |
#words ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1WordInfo>
Output only. A list of word-specific information for each recognized word.
Note: When enable_speaker_diarization is set to true, you will see all the
words from the beginning of the audio.
Corresponds to the JSON property words
3084 3085 3086 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3084 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3091 3092 3093 3094 3095 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3091 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @transcript = args[:transcript] if args.key?(:transcript) @words = args[:words] if args.key?(:words) end |