Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1DetectedLandmark
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1DetectedLandmark
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
A generic detected landmark represented by name in string format and a 2D location.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
The confidence score of the detected landmark.
-
#name ⇒ String
The name of this landmark, for example, left_hand, right_shoulder.
-
#point ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1NormalizedVertex
A vertex represents a 2D point in the image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1DetectedLandmark
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1DetectedLandmark.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1DetectedLandmark
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1DetectedLandmark.
3752 3753 3754 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
The confidence score of the detected landmark. Range [0, 1].
Corresponds to the JSON property confidence
3739 3740 3741 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3739 def confidence @confidence end |
#name ⇒ String
The name of this landmark, for example, left_hand, right_shoulder.
Corresponds to the JSON property name
3744 3745 3746 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3744 def name @name end |
#point ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1NormalizedVertex
A vertex represents a 2D point in the image. NOTE: the normalized vertex
coordinates are relative to the original image and range from 0 to 1.
Corresponds to the JSON property point
3750 3751 3752 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3750 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3757 3758 3759 3760 3761 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3757 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @name = args[:name] if args.key?(:name) @point = args[:point] if args.key?(:point) end |