Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1FaceFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Deprecated. No effect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1FaceFrame

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1FaceFrame.



4014
4015
4016
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#normalized_bounding_boxesArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1NormalizedBoundingBox>

Normalized Bounding boxes in a frame. There can be more than one boxes if the same face is detected in multiple locations within the current frame. Corresponds to the JSON property normalizedBoundingBoxes



4006
4007
4008
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4006

def normalized_bounding_boxes
  @normalized_bounding_boxes
end

#time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the video frame for this location. Corresponds to the JSON property timeOffset

Returns:

  • (String)


4012
4013
4014
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4012

def time_offset
  @time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4019
4020
4021
4022
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4019

def update!(**args)
  @normalized_bounding_boxes = args[:normalized_bounding_boxes] if args.key?(:normalized_bounding_boxes)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
end