Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1LabelAnnotation.



4075
4076
4077
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



4053
4054
4055
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4053

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



4058
4059
4060
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4058

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



4063
4064
4065
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4063

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



4068
4069
4070
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4068

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


4073
4074
4075
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4073

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4080
4081
4082
4083
4084
4085
4086
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4080

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end