Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation.



4217
4218
4219
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



4203
4204
4205
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4203

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



4209
4210
4211
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4209

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



4215
4216
4217
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4215

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4222
4223
4224
4225
4226
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4222

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end