Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Provides "hints" to the speech recognizer to favor specific words and phrases in the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1SpeechContext

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1SpeechContext.



4518
4519
4520
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4518

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#phrasesArray<String>

Optional. A list of strings containing words and phrases "hints" so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits. Corresponds to the JSON property phrases

Returns:

  • (Array<String>)


4516
4517
4518
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4516

def phrases
  @phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4523
4524
4525
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4523

def update!(**args)
  @phrases = args[:phrases] if args.key?(:phrases)
end