Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Alternative hypotheses (a.k.a. n-best list).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative.



4554
4555
4556
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Output only. The confidence estimate between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. This field is set only for the top alternative. This field is not guaranteed to be accurate and users should not rely on it to be always provided. The default of 0.0 is a sentinel value indicating confidence was not set. Corresponds to the JSON property confidence

Returns:

  • (Float)


4540
4541
4542
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4540

def confidence
  @confidence
end

#transcriptString

Transcript text representing the words that the user spoke. Corresponds to the JSON property transcript

Returns:

  • (String)


4545
4546
4547
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4545

def transcript
  @transcript
end

#wordsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1WordInfo>

Output only. A list of word-specific information for each recognized word. Note: When enable_speaker_diarization is set to true, you will see all the words from the beginning of the audio. Corresponds to the JSON property words



4552
4553
4554
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4552

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4559
4560
4561
4562
4563
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4559

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @transcript = args[:transcript] if args.key?(:transcript)
  @words = args[:words] if args.key?(:words)
end