Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

A speech recognition result corresponding to a portion of the audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1SpeechTranscription

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1SpeechTranscription.



4585
4586
4587
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechRecognitionAlternative>

May contain one or more recognition hypotheses (up to the maximum specified in max_alternatives). These alternatives are ordered in terms of accuracy, with the top (first) alternative being the most probable, as ranked by the recognizer. Corresponds to the JSON property alternatives



4576
4577
4578
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4576

def alternatives
  @alternatives
end

#language_codeString

Output only. The BCP-47 language tag of the language in this result. This language code was detected to have the most likelihood of being spoken in the audio. Corresponds to the JSON property languageCode

Returns:

  • (String)


4583
4584
4585
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4583

def language_code
  @language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4590
4591
4592
4593
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4590

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @language_code = args[:language_code] if args.key?(:language_code)
end