Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Config for TEXT_DETECTION.
Instance Attribute Summary collapse
-
#language_hints ⇒ Array<String>
Language hint can be specified if the language to be detected is known a priori.
-
#model ⇒ String
Model to use for text detection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1TextDetectionConfig.
4749 4750 4751 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_hints ⇒ Array<String>
Language hint can be specified if the language to be detected is known a
priori. It can increase the accuracy of the detection. Language hint must be
language code in BCP-47 format. Automatic language detection is performed if
no hint is provided.
Corresponds to the JSON property languageHints
4741 4742 4743 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4741 def language_hints @language_hints end |
#model ⇒ String
Model to use for text detection. Supported values: "builtin/stable" (the
default if unset) and "builtin/latest".
Corresponds to the JSON property model
4747 4748 4749 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4747 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4754 4755 4756 4757 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4754 def update!(**args) @language_hints = args[:language_hints] if args.key?(:language_hints) @model = args[:model] if args.key?(:model) end |