Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Track
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1Track
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
A track of an object instance.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1DetectedAttribute>
Optional.
-
#confidence ⇒ Float
Optional.
-
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
-
#timestamped_objects ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1TimestampedObject>
The object with timestamp and attributes per frame in the track.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1Track
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1Track.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1Track
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1Track.
4889 4890 4891 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1DetectedAttribute>
Optional. Attributes in the track level.
Corresponds to the JSON property attributes
4872 4873 4874 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4872 def attributes @attributes end |
#confidence ⇒ Float
Optional. The confidence score of the tracked object.
Corresponds to the JSON property confidence
4877 4878 4879 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4877 def confidence @confidence end |
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
4882 4883 4884 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4882 def segment @segment end |
#timestamped_objects ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1TimestampedObject>
The object with timestamp and attributes per frame in the track.
Corresponds to the JSON property timestampedObjects
4887 4888 4889 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4887 def @timestamped_objects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4894 4895 4896 4897 4898 4899 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4894 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @confidence = args[:confidence] if args.key?(:confidence) @segment = args[:segment] if args.key?(:segment) @timestamped_objects = args[:timestamped_objects] if args.key?(:timestamped_objects) end |