Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb

Overview

Annotation results for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationResults.



5068
5069
5070
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



4971
4972
4973
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4971

def error
  @error
end

#explicit_annotationGoogle::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame. Corresponds to the JSON property explicitAnnotation



4978
4979
4980
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4978

def explicit_annotation
  @explicit_annotation
end

#face_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1FaceAnnotation>

Deprecated. Please use face_detection_annotations instead. Corresponds to the JSON property faceAnnotations



4983
4984
4985
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4983

def face_annotations
  @face_annotations
end

#face_detection_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1FaceDetectionAnnotation>

Face detection annotations. Corresponds to the JSON property faceDetectionAnnotations



4988
4989
4990
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4988

def face_detection_annotations
  @face_detection_annotations
end

#frame_label_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>

Label annotations on frame level. There is exactly one element for each unique label. Corresponds to the JSON property frameLabelAnnotations



4994
4995
4996
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4994

def frame_label_annotations
  @frame_label_annotations
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


4999
5000
5001
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4999

def input_uri
  @input_uri
end

#logo_recognition_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LogoRecognitionAnnotation>

Annotations for list of logos detected, tracked and recognized in video. Corresponds to the JSON property logoRecognitionAnnotations



5004
5005
5006
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5004

def logo_recognition_annotations
  @logo_recognition_annotations
end

#object_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation>

Annotations for list of objects detected and tracked in video. Corresponds to the JSON property objectAnnotations



5009
5010
5011
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5009

def object_annotations
  @object_annotations
end

#person_detection_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1PersonDetectionAnnotation>

Person detection annotations. Corresponds to the JSON property personDetectionAnnotations



5014
5015
5016
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5014

def person_detection_annotations
  @person_detection_annotations
end

#segmentGoogle::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment

Video segment. Corresponds to the JSON property segment



5019
5020
5021
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5019

def segment
  @segment
end

#segment_label_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>

Topical label annotations on video level or user-specified segment level. There is exactly one element for each unique label. Corresponds to the JSON property segmentLabelAnnotations



5025
5026
5027
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5025

def segment_label_annotations
  @segment_label_annotations
end

#segment_presence_label_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>

Presence label annotations on video level or user-specified segment level. There is exactly one element for each unique label. Compared to the existing topical segment_label_annotations, this field presents more fine-grained, segment-level labels detected in video content and is made available only when the client sets LabelDetectionConfig.model to "builtin/latest" in the request. Corresponds to the JSON property segmentPresenceLabelAnnotations



5035
5036
5037
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5035

def segment_presence_label_annotations
  @segment_presence_label_annotations
end

#shot_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment>

Shot annotations. Each shot is represented as a video segment. Corresponds to the JSON property shotAnnotations



5040
5041
5042
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5040

def shot_annotations
  @shot_annotations
end

#shot_label_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>

Topical label annotations on shot level. There is exactly one element for each unique label. Corresponds to the JSON property shotLabelAnnotations



5046
5047
5048
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5046

def shot_label_annotations
  @shot_label_annotations
end

#shot_presence_label_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation>

Presence label annotations on shot level. There is exactly one element for each unique label. Compared to the existing topical shot_label_annotations, this field presents more fine-grained, shot-level labels detected in video content and is made available only when the client sets LabelDetectionConfig. model to "builtin/latest" in the request. Corresponds to the JSON property shotPresenceLabelAnnotations



5055
5056
5057
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5055

def shot_presence_label_annotations
  @shot_presence_label_annotations
end

#speech_transcriptionsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscription>

Speech transcription. Corresponds to the JSON property speechTranscriptions



5060
5061
5062
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5060

def speech_transcriptions
  @speech_transcriptions
end

#text_annotationsArray<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1TextAnnotation>

OCR text detection and tracking. Annotations for list of detected text snippets. Each will have list of frame information associated with it. Corresponds to the JSON property textAnnotations



5066
5067
5068
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5066

def text_annotations
  @text_annotations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5073
5074
5075
5076
5077
5078
5079
5080
5081
5082
5083
5084
5085
5086
5087
5088
5089
5090
5091
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 5073

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation)
  @face_annotations = args[:face_annotations] if args.key?(:face_annotations)
  @face_detection_annotations = args[:face_detection_annotations] if args.key?(:face_detection_annotations)
  @frame_label_annotations = args[:frame_label_annotations] if args.key?(:frame_label_annotations)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @logo_recognition_annotations = args[:logo_recognition_annotations] if args.key?(:logo_recognition_annotations)
  @object_annotations = args[:object_annotations] if args.key?(:object_annotations)
  @person_detection_annotations = args[:person_detection_annotations] if args.key?(:person_detection_annotations)
  @segment = args[:segment] if args.key?(:segment)
  @segment_label_annotations = args[:segment_label_annotations] if args.key?(:segment_label_annotations)
  @segment_presence_label_annotations = args[:segment_presence_label_annotations] if args.key?(:segment_presence_label_annotations)
  @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations)
  @shot_label_annotations = args[:shot_label_annotations] if args.key?(:shot_label_annotations)
  @shot_presence_label_annotations = args[:shot_presence_label_annotations] if args.key?(:shot_presence_label_annotations)
  @speech_transcriptions = args[:speech_transcriptions] if args.key?(:speech_transcriptions)
  @text_annotations = args[:text_annotations] if args.key?(:text_annotations)
end