Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Status of exporting annotation response to user specified output_uri.
Instance Attribute Summary collapse
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus.
2613 2614 2615 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
Output only. State of the output_uri export.
Corresponds to the JSON property state
2601 2602 2603 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2601 def state @state end |
#status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
2611 2612 2613 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2611 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2618 2619 2620 2621 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 2618 def update!(**args) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) end |