Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.
Instance Attribute Summary collapse
-
#frames ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentFrame>
All video frames where explicit content was detected.
-
#version ⇒ String
Feature version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1ExplicitContentAnnotation.
3812 3813 3814 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frames ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExplicitContentFrame>
All video frames where explicit content was detected.
Corresponds to the JSON property frames
3805 3806 3807 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3805 def frames @frames end |
#version ⇒ String
Feature version.
Corresponds to the JSON property version
3810 3811 3812 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3810 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3817 3818 3819 3820 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 3817 def update!(**args) @frames = args[:frames] if args.key?(:frames) @version = args[:version] if args.key?(:version) end |