Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Config for SPEECH_TRANSCRIPTION.
Instance Attribute Summary collapse
-
#audio_output_uri_prefix ⇒ String
Optional.
-
#audio_tracks ⇒ Array<Fixnum>
Optional.
-
#diarization_speaker_count ⇒ Fixnum
Optional.
-
#enable_automatic_punctuation ⇒ Boolean
(also: #enable_automatic_punctuation?)
Optional.
-
#enable_speaker_diarization ⇒ Boolean
(also: #enable_speaker_diarization?)
Optional.
-
#enable_word_confidence ⇒ Boolean
(also: #enable_word_confidence?)
Optional.
-
#filter_profanity ⇒ Boolean
(also: #filter_profanity?)
Optional.
-
#language_code ⇒ String
Required.
-
#max_alternatives ⇒ Fixnum
Optional.
-
#speech_contexts ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechContext>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1SpeechTranscriptionConfig.
4679 4680 4681 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_output_uri_prefix ⇒ String
Optional. Legacy field. This field must be a Cloud Storage URI prefix. (e.g.,
gs://bucket/path/).
Corresponds to the JSON property audioOutputUriPrefix
4604 4605 4606 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4604 def audio_output_uri_prefix @audio_output_uri_prefix end |
#audio_tracks ⇒ Array<Fixnum>
Optional. For file formats, such as MXF or MKV, supporting multiple audio
tracks, specify up to two tracks. Default: track 0.
Corresponds to the JSON property audioTracks
4610 4611 4612 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4610 def audio_tracks @audio_tracks end |
#diarization_speaker_count ⇒ Fixnum
Optional. If set, specifies the estimated number of speakers in the
conversation. If not set, defaults to '2'. Ignored unless
enable_speaker_diarization is set to true.
Corresponds to the JSON property diarizationSpeakerCount
4617 4618 4619 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4617 def diarization_speaker_count @diarization_speaker_count end |
#enable_automatic_punctuation ⇒ Boolean Also known as: enable_automatic_punctuation?
Optional. If 'true', adds punctuation to recognition result hypotheses. This
feature is only available in select languages. Setting this for requests in
other languages has no effect at all. The default 'false' value does not add
punctuation to result hypotheses. NOTE: "This is currently offered as an
experimental service, complimentary to all users. In the future this may be
exclusively available as a premium feature."
Corresponds to the JSON property enableAutomaticPunctuation
4627 4628 4629 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4627 def enable_automatic_punctuation @enable_automatic_punctuation end |
#enable_speaker_diarization ⇒ Boolean Also known as: enable_speaker_diarization?
Optional. If 'true', enables speaker detection for each recognized word in the
top alternative of the recognition result using a speaker_tag provided in the
WordInfo. Note: When this is true, we send all the words from the beginning of
the audio for the top alternative in every consecutive response. This is done
in order to improve our speaker tags as our models learn to identify the
speakers in the conversation over time.
Corresponds to the JSON property enableSpeakerDiarization
4638 4639 4640 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4638 def enable_speaker_diarization @enable_speaker_diarization end |
#enable_word_confidence ⇒ Boolean Also known as: enable_word_confidence?
Optional. If true, the top result includes a list of words and the
confidence for those words. If false, no word-level confidence information
is returned. The default is false.
Corresponds to the JSON property enableWordConfidence
4646 4647 4648 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4646 def enable_word_confidence @enable_word_confidence end |
#filter_profanity ⇒ Boolean Also known as: filter_profanity?
Optional. If set to true, the server will attempt to filter out profanities,
replacing all but the initial character in each filtered word with asterisks,
e.g. "f***". If set to false or omitted, profanities won't be filtered out.
Corresponds to the JSON property filterProfanity
4654 4655 4656 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4654 def filter_profanity @filter_profanity end |
#language_code ⇒ String
Required. Required The language of the supplied audio as a BCP-47 language tag. Example: "en-US". See
Language Support for a list
of the currently supported language codes.
Corresponds to the JSON property languageCode
4663 4664 4665 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4663 def language_code @language_code end |
#max_alternatives ⇒ Fixnum
Optional. Maximum number of recognition hypotheses to be returned.
Specifically, the maximum number of SpeechRecognitionAlternative messages
within each SpeechTranscription. The server may return fewer than
max_alternatives. Valid values are 0-30. A value of 0 or 1 will
return a maximum of one. If omitted, will return a maximum of one.
Corresponds to the JSON property maxAlternatives
4672 4673 4674 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4672 def max_alternatives @max_alternatives end |
#speech_contexts ⇒ Array<Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1SpeechContext>
Optional. A means to provide context to assist the speech recognition.
Corresponds to the JSON property speechContexts
4677 4678 4679 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4677 def speech_contexts @speech_contexts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4684 4685 4686 4687 4688 4689 4690 4691 4692 4693 4694 4695 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4684 def update!(**args) @audio_output_uri_prefix = args[:audio_output_uri_prefix] if args.key?(:audio_output_uri_prefix) @audio_tracks = args[:audio_tracks] if args.key?(:audio_tracks) @diarization_speaker_count = args[:diarization_speaker_count] if args.key?(:diarization_speaker_count) @enable_automatic_punctuation = args[:enable_automatic_punctuation] if args.key?(:enable_automatic_punctuation) @enable_speaker_diarization = args[:enable_speaker_diarization] if args.key?(:enable_speaker_diarization) @enable_word_confidence = args[:enable_word_confidence] if args.key?(:enable_word_confidence) @filter_profanity = args[:filter_profanity] if args.key?(:filter_profanity) @language_code = args[:language_code] if args.key?(:language_code) @max_alternatives = args[:max_alternatives] if args.key?(:max_alternatives) @speech_contexts = args[:speech_contexts] if args.key?(:speech_contexts) end |