Class: Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1p2beta1/classes.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb,
lib/google/apis/videointelligence_v1p2beta1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.
4943 4944 4945 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
4909 4910 4911 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4909 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
4915 4916 4917 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4915 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
4920 4921 4922 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4920 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
4926 4927 4928 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4926 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1p2beta1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
4931 4932 4933 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4931 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
4936 4937 4938 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4936 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
4941 4942 4943 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4941 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4948 4949 4950 4951 4952 4953 4954 4955 4956 |
# File 'lib/google/apis/videointelligence_v1p2beta1/classes.rb', line 4948 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |